@@ -29,7 +29,6 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libart_lgpl/libart.h>
-#include <egg-screen-exec.h>
 
 #include "global.h"
 
@@ -38,29 +37,31 @@ about_cb (BonoboUIComponent *uic,
 	  MultiloadApplet   *ma,
 	  const char        *name)
 {
-    static GtkWidget *about = NULL;
     GdkPixbuf        *pixbuf;
     GError           *error = NULL;
     gchar            *file;
    
     static const gchar *authors[] =
-	{
+    {
 		"Martin Baulig <martin@home-of-linux.org>",
 		"Todd Kulesza <fflewddur@dropline.net>\n",
 		NULL
-	};
+    };
 
     const gchar *documenters[] =
-	{
+    {
+		"Chee Bin HOH <cbhoh@gnome.org>",
+		"Sun GNOME Documentation Team <gdocteam@sun.com>",
 		NULL
-	};
+    };
 
     const gchar *translator_credits = _("translator_credits");
 
-    if (about) {
-	gtk_window_set_screen (GTK_WINDOW (about),
+    if (ma->about_dialog) {
+	gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
-	gtk_window_present (GTK_WINDOW (about));
+
+	gtk_window_present (GTK_WINDOW (ma->about_dialog));
 	return;
     }
 	
@@ -68,33 +69,54 @@ about_cb (BonoboUIComponent *uic,
     pixbuf = gdk_pixbuf_new_from_file (file, &error);
     g_free (file);
    
-    if (error) 
-    	{
-   	    g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-	    g_error_free (error);
-   	}
+    if (error) {
+	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	g_error_free (error);
+    }
 
 	
-    about = gnome_about_new
-	(_("System Monitor"), VERSION,
-	 "(C) 1999 - 2002 The Free Software Foundation",
-	 _("Released under the GNU General Public License.\n\n"
-	   "A system load monitor capable of displaying graphs for CPU, ram, and swap space use, plus network traffic."),
-	 authors,
-	 documenters,
-	 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-	 pixbuf);
+    ma->about_dialog = gnome_about_new (_("System Monitor"), VERSION,
+					"(C) 1999 - 2002 The Free Software Foundation",
+					_("Released under the GNU General Public License.\n\n"
+					  "A system load monitor capable of displaying graphs for CPU, ram, and swap space use, plus network traffic."),
+					authors,
+					documenters,
+					strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+					pixbuf);
 
     if (pixbuf) 
-   	gdk_pixbuf_unref (pixbuf);
+	g_object_unref (pixbuf);
   
-    gtk_window_set_screen (GTK_WINDOW (about),
-   			   gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
-    gtk_window_set_wmclass (GTK_WINDOW (about), "system monitor", "System Monitor");
-    g_signal_connect (G_OBJECT (about), "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &about);
+    gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
+			   gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
+    gtk_window_set_wmclass (GTK_WINDOW (ma->about_dialog), "system monitor",
+			    "System Monitor");
+    g_signal_connect (G_OBJECT (ma->about_dialog), "destroy",
+		      G_CALLBACK (gtk_widget_destroyed), &ma->about_dialog);
+
+    gtk_widget_show (ma->about_dialog);
+}
+
+static void
+help_cb (BonoboUIComponent *uic,
+	  MultiloadApplet   *ma,
+	  const char        *name)
+{
+
+ 	GError *error = NULL;
+                                                                                
+    	gnome_help_display_on_screen (
+                "multiload", NULL,
+                gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
+                &error);
+                                                                                
+    	if (error) { /* FIXME: the user needs to see this */
+        	g_warning ("help error: %s\n", error->message);
+        	g_error_free (error);
+        	error = NULL;
+    	}
+
 
-    gtk_widget_show (about);
 }
 
 /* run the full-scale system process monitor */
@@ -105,10 +127,11 @@ start_procman (MultiloadApplet *ma)
 	GError *error = NULL;
 
 	g_return_if_fail (ma != NULL);
-	
-	egg_screen_execute_command_line_async (
+
+	gdk_spawn_command_line_on_screen (
 			gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
 			"gnome-system-monitor", &error);
+
 	if (error) {
 		GtkWidget *dialog;
 
@@ -161,17 +184,48 @@ multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 	return;
 }
 
+void
+multiload_change_background_cb(PanelApplet *a, PanelAppletBackgroundType type,
+				GdkColor *color, GdkPixmap *pixmap,
+				gpointer *data)
+{
+	MultiloadApplet *ma = (MultiloadApplet *)data;
+	GtkRcStyle *rc_style = gtk_rc_style_new ();
+
+	switch (type) {
+		case PANEL_PIXMAP_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+			break;
+
+		case PANEL_COLOR_BACKGROUND:
+			gtk_widget_modify_bg (GTK_WIDGET (ma->applet), GTK_STATE_NORMAL, color);
+			break;
+
+		case PANEL_NO_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+			break;
+
+		default:
+			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+			break;
+	}
+
+	gtk_rc_style_unref (rc_style);
+}
+
 void
 multiload_destroy_cb(GtkWidget *widget, gpointer data)
 {
 	gint i;
 	MultiloadApplet *ma = data;
-	
+
 	for (i = 0; i < NGRAPHS; i++)
 	{
 		if (ma->graphs[i]->visible)
 		{
 			load_graph_stop(ma->graphs[i]);
+			g_free (ma->graphs[i]->colors);
+			ma->graphs[i]->colors = NULL;
 			gtk_widget_destroy(ma->graphs[i]->main_widget);
 		}
 		
@@ -179,8 +233,16 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 		g_free(ma->graphs[i]);
 	}
 	
+	if (ma->about_dialog)
+		gtk_widget_destroy (ma->about_dialog);
+	
+	if (ma->prop_dialog)
+		gtk_widget_destroy (ma->prop_dialog);
+
 	gtk_widget_destroy(GTK_WIDGET(ma->applet));
-			
+
+	g_free (ma);
+
 	return;
 }
 
@@ -260,7 +322,7 @@ multiload_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MultiloadAp
 void
 multiload_applet_tooltip_update(LoadGraph *g)
 {
-	gint i, total_used, percent;
+	gint i, total_used, percent, mem_used, used_percent;
 	gchar *tooltip_text, *name;
 
 	g_return_if_fail(g);
@@ -291,7 +353,16 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	percent = 100 * (gdouble)total_used / (gdouble)g->draw_height;
 	percent = CLAMP (percent, 0, 100);
 
-	tooltip_text = g_strdup_printf(_("%s:\n%d%% in use"), name, percent);
+	if (!strncmp(g->name, "memload", strlen("memload"))) {
+		mem_used = total_used - g->data[0][i - 1];
+		used_percent = 100 * (gdouble)mem_used / (gdouble)g->draw_height;
+		used_percent = CLAMP (used_percent, 0, 100);
+		
+		tooltip_text = g_strdup_printf(_("%s:\n%d%% in use of which\n%d%% is cache"), name, percent,
+				percent - used_percent);
+	} else
+		tooltip_text = g_strdup_printf(_("%s:\n%d%% in use"), name, percent);
+	
 	gtk_tooltips_set_tip(g->tooltips, g->disp, tooltip_text, tooltip_text);
 		
 	g_free(tooltip_text);
@@ -364,6 +435,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 static const BonoboUIVerb multiload_menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("MultiLoadProperties", multiload_properties_cb),
 	BONOBO_UI_UNSAFE_VERB ("MultiLoadRunProcman", start_procman_cb),
+	BONOBO_UI_UNSAFE_VERB ("MultiLoadHelp", help_cb),
 	BONOBO_UI_UNSAFE_VERB ("MultiLoadAbout", about_cb),
 
 	BONOBO_UI_VERB_END
@@ -381,6 +453,9 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	
 	ma->applet = applet;
 	
+	ma->about_dialog = NULL;
+	ma->prop_dialog = NULL;
+
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-monitor.png");
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
@@ -417,6 +492,8 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 				G_CALLBACK(multiload_change_size_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "change_orient",
 				G_CALLBACK(multiload_change_orient_cb), ma);
+	g_signal_connect(G_OBJECT(applet), "change_background",
+				G_CALLBACK(multiload_change_background_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "destroy",
 				G_CALLBACK(multiload_destroy_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "enter_notify_event",
@@ -447,7 +524,7 @@ multiload_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MultiLoadApplet_Factory",
 				   PANEL_TYPE_APPLET,
-				   "MultiLoad Applet factory",
+				   "multiload",
 				   "0",
 				   multiload_factory,
 				   NULL);
