@@ -21,7 +21,7 @@
 #include <stickynotes_applet_callbacks.h>
 #include <stickynotes.h>
 
-#include <egg-screen-help.h>
+#include <libgnome/gnome-help.h>
 
 /* Applet Callback : Mouse button press on the applet. */
 gboolean applet_button_cb(GtkWidget *widget, GdkEventButton *event, StickyNotesApplet *applet)
@@ -30,7 +30,7 @@ gboolean applet_button_cb(GtkWidget *widget, GdkEventButton *event, StickyNotesA
 		applet->pressed = TRUE;
 	
 	else if (event->type == GDK_BUTTON_RELEASE && event->button == 1) {
-		stickynotes_applet_do_default_action();	
+		stickynotes_applet_do_default_action(gtk_widget_get_screen(applet->w_applet));	
 		applet->pressed = FALSE;
 	}
 	
@@ -46,7 +46,7 @@ gboolean applet_button_cb(GtkWidget *widget, GdkEventButton *event, StickyNotesA
 gboolean applet_key_cb(GtkWidget *widget, GdkEventKey *event, StickyNotesApplet *applet)
 {
 	if (event->type == GDK_KEY_PRESS && event->keyval == GDK_Return)
-		stickynotes_applet_do_default_action();	
+		stickynotes_applet_do_default_action(gtk_widget_get_screen(applet->w_applet));	
 	else
 		return FALSE;
 	
@@ -81,12 +81,30 @@ gboolean applet_save_cb(StickyNotesApplet *applet)
 	return TRUE;
 }
 
-/* Applet Callback : Resize the applet. */
-gboolean applet_change_size_cb(GtkWidget *widget, gint size, StickyNotesApplet *applet)
+/* Applet Callback : Change the panel orientation. */
+void applet_change_orient_cb(PanelApplet *panel_applet, PanelAppletOrient orient, StickyNotesApplet *applet)
 {
+	applet->panel_orient = orient;
+
+	return;
+}
+
+/* Applet Callback : Resize the applet. */
+void applet_size_allocate_cb(GtkWidget *widget, GtkAllocation *allocation, StickyNotesApplet *applet)
+{
+	if ((applet->panel_orient == PANEL_APPLET_ORIENT_UP) || (applet->panel_orient == PANEL_APPLET_ORIENT_DOWN)) {
+	  if (applet->panel_size == allocation->height)
+	    return;
+	  applet->panel_size = allocation->height;
+	} else {
+	  if (applet->panel_size == allocation->width)
+	    return;
+	  applet->panel_size = allocation->width;
+	}
+
 	stickynotes_applet_update_icon(applet);
 
-	return FALSE;
+	return;
 }
 
 /* Applet Callback : Change the applet background. */
@@ -113,38 +131,79 @@ gboolean applet_change_bg_cb(PanelApplet *panel_applet, PanelAppletBackgroundTyp
 /* Applet Callback : Deletes the applet. */
 void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet)
 {
+	GList *notes;
+	
+	if (applet->destroy_all_dialog != NULL)
+		gtk_widget_destroy (applet->destroy_all_dialog);
+
 	if (applet->about_dialog != NULL)
 		gtk_widget_destroy (applet->about_dialog);
 	
 	if (stickynotes->applets != NULL)
 		stickynotes->applets = g_list_remove (stickynotes->applets, applet);
+		
+	if (stickynotes->applets == NULL) {
+               notes = stickynotes->notes;
+               while (notes) {
+                       StickyNote *note = notes->data;
+                       stickynote_free (note);
+                       notes = g_list_next (notes);
+               }
+	}
+	
+	
 }		
 
 /* Menu Callback : Create a new sticky note */
 void menu_create_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
-	stickynotes_add();
+	stickynotes_add(gtk_widget_get_screen(applet->w_applet));
+}
+
+/* Destroy all response Callback: Callback for the destroy all dialog */
+static void
+destroy_all_response_cb (GtkDialog *dialog, gint id, StickyNotesApplet *applet)
+{
+	if (id == GTK_RESPONSE_OK) {
+		while (g_list_length(stickynotes->notes) > 0) {
+			StickyNote *note = g_list_nth_data(stickynotes->notes, 0);
+			stickynote_free(note);
+			stickynotes->notes = g_list_remove(stickynotes->notes, note);
+		}							       
+	}
+
+	stickynotes_applet_update_tooltips();
+	stickynotes_save();
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	applet->destroy_all_dialog = NULL;
 }
 
 /* Menu Callback : Destroy all sticky notes */
 void menu_destroy_all_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
 	GladeXML *glade = glade_xml_new(GLADE_PATH, "delete_all_dialog", NULL);
-	GtkWidget *dialog = glade_xml_get_widget(glade, "delete_all_dialog");
 
-	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
-		while (g_list_length(stickynotes->notes) > 0) {
-			StickyNote *note = g_list_nth_data(stickynotes->notes, 0);
-			stickynote_free(note);
-			stickynotes->notes = g_list_remove(stickynotes->notes, note);
-		}
+	if (applet->destroy_all_dialog != NULL) {
+		gtk_window_set_screen (GTK_WINDOW (applet->destroy_all_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (applet->w_applet)));
+
+		gtk_window_present (GTK_WINDOW (applet->destroy_all_dialog));
+		return;
 	}
-		
-	stickynotes_applet_update_tooltips();
-	stickynotes_save();
+	
+	applet->destroy_all_dialog = glade_xml_get_widget(glade, "delete_all_dialog");
 
-	gtk_widget_destroy(dialog);
-	g_object_unref(glade);
+	g_object_unref (glade);
+
+	g_signal_connect (applet->destroy_all_dialog, "response",
+			  G_CALLBACK (destroy_all_response_cb),
+			  applet);
+
+	gtk_window_set_screen (GTK_WINDOW (applet->destroy_all_dialog),
+			gtk_widget_get_screen (applet->w_applet));
+
+	gtk_widget_show_all (applet->destroy_all_dialog);
 }
 
 /* Menu Callback : Show/Hide sticky notes */
@@ -173,7 +232,7 @@ void menu_preferences_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, cons
 void menu_help_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
 	GError *error = NULL;
-	egg_help_display_on_screen("stickynotes_applet", "stickynotes-introduction", gtk_widget_get_screen(applet->w_applet), &error);
+	gnome_help_display_on_screen("stickynotes_applet", "stickynotes-introduction", gtk_widget_get_screen(applet->w_applet), &error);
 	if (error) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 							   _("There was an error displaying help: %s"), error->message);
@@ -218,6 +277,9 @@ void menu_about_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gcha
 					       strcmp(translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 					       stickynotes->icon_normal);
 
+	gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (applet->w_applet)));
+
 	g_signal_connect (applet->about_dialog, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &applet->about_dialog);
@@ -334,7 +396,7 @@ void preferences_response_cb(GtkDialog *dialog, gint response, gpointer data)
 {
 	if (response == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
-		egg_help_display_on_screen("stickynotes_applet", "stickynotes-advanced-settings", gtk_widget_get_screen(GTK_WIDGET(dialog)), &error);
+		gnome_help_display_on_screen("stickynotes_applet", "stickynotes-advanced-settings", gtk_widget_get_screen(GTK_WIDGET(dialog)), &error);
 		if (error) {
 			GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 								   _("There was an error displaying help: %s"), error->message);
